[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)
[![PyPI badge](http://img.shields.io/pypi/v/scippnexus.svg)](https://pypi.python.org/pypi/scippnexus)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/scippnexus/badges/version.svg)](https://anaconda.org/conda-forge/scippnexus)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)
[![DOI](https://zenodo.org/badge/475453428.svg)](https://zenodo.org/badge/latestdoi/475453428)

# ScippNexus

## About

ScippNexus is a h5py-like utility for NeXus files with seamless scipp integration.
See the [documentation](https://scipp.github.io/scippnexus) for more details.

## Installation

```sh
python -m pip install scippnexus
```
